@@ -1,5 +1,8 @@
 from .application import Application as Application, run_app as run_app
-from .device_agent import DeviceAgentInterface as DeviceAgentInterface
+from .device_agent import (
+    DeviceAgentInterface as DeviceAgentInterface,
+    MockDeviceAgentInterface as MockDeviceAgentInterface,
+)
 from .modbus import (
     ModbusInterface as ModbusInterface,
     ModbusConfig as ModbusConfig,
